{% extends "base.html" %}

{% block content %}

  <h1 id="search">Search Results</h1>

  <form id="content_search" action="search.html">
    <span role="status" aria-live="polite" class="ui-helper-hidden-accessible"></span>
    <input name="q" id="mkdocs-search-query" type="text" class="search_input search-query ui-autocomplete-input" placeholder="Search the Docs" autocomplete="off">
  </form>

  <div id="mkdocs-search-results">
    Sorry, page not found.
  </div>

{% endblock %}
